import { EventBus, Publish } from "./EventBus";
import { DocumentNode, GraphQLSchema } from "graphql";
export declare type DataCb = (data: {}) => void;
interface SubscriptionConfig {
    queries: DocumentNode;
    schema: GraphQLSchema;
    cb: (bus: VanillaEventBus) => EventBusSubscriberCb;
    getSubscription: (topic: string, cb: DataCb) => void;
}
export declare type EventBusSubscriberCb = (props: {
    key: string;
    data: {};
}) => Promise<any>;
export interface EventBusPlugin {
    consumeStart?: (args: {
        topic: string;
    }) => void;
    consumeEnd?: (args: {
        topic: string;
    }) => void;
    consumeError?: (err: Error) => void;
    publishError?: (err: Error) => void;
    publishStart?: (args: {
        topic: string;
    }) => void;
    publishEnd?: (args: {
        topic: string;
    }) => void;
}
export declare class VanillaEventBus implements EventBus {
    config: {
        publisher?: {
            schema: GraphQLSchema;
            publishInit?: (topics: string[]) => Promise<unknown>;
            publishClose?: (topics: string[]) => Promise<unknown>;
        };
        subscriber?: SubscriptionConfig;
        plugins?: EventBusPlugin[];
    };
    private consumeValidator;
    private publishValidator;
    private subscribeTopics;
    private publishTopics;
    constructor(config: {
        publisher?: {
            schema: GraphQLSchema;
            publishInit?: (topics: string[]) => Promise<unknown>;
            publishClose?: (topics: string[]) => Promise<unknown>;
        };
        subscriber?: SubscriptionConfig;
        plugins?: EventBusPlugin[];
    });
    init: () => Promise<void>;
    private consume;
    publish: Publish;
    closeConsumer: () => Promise<void>;
    closePublisher: () => Promise<void>;
}
export {};
